﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

namespace howto_array_to_string
{
    public static class Extensions
    {
        public static string Join<T>(this T[] values, string delimiter)
        {
            if (values.Length == 0) return "";

            StringBuilder sb = new StringBuilder();
            sb.Append(values[0].ToString());

            for (int i = 1; i < values.Length; i++)
            {
                sb.Append(delimiter + values[i].ToString());
            }
            return sb.ToString();
        }

        // Convert the string containing a
        // delimited list into a T[].
        public static T[] SpiltTs<T>(this string values_text,
            string separator, StringSplitOptions split_options,
            Converter<string, T> converter)
        {
            string[] values_array =
                values_text.Split(separator, split_options);
            return Array.ConvertAll<string, T>
                (values_array, converter);
        }

        public static int[] SplitInts(this string values_text,
            string separator, StringSplitOptions split_options)
        {
            return values_text.SpiltTs<int>(
                separator, split_options, int.Parse);
        }
        public static float[] SplitFloats(this string values_text,
            string separator, StringSplitOptions split_options)
        {
            return values_text.SpiltTs<float>(
                separator, split_options, float.Parse);
        }

        public static string[] Split(this string values_text,
            string delimiter, StringSplitOptions split_options)
        {
            string[] separators = { delimiter };
            return values_text.Split(separators, split_options);
        }
    }
}
